<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */
if ( ! function_exists( 'travel_master_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Travel Master Pro 1.0.0
    */
    function travel_master_pro_add_about_section() {
    	$options = travel_master_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'travel_master_pro_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'travel_master_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        travel_master_pro_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'travel_master_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Travel Master Pro 1.0.0
    * @param array $input about section details.
    */
    function travel_master_pro_get_about_section_details( $input ) {
        $options = travel_master_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        
        $content = array();
        switch ( $about_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['about_title'] ) ? $options['about_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_description'] ) ? $options['about_description'] : '';
                $custom['url']          = ! empty( $options['about_btn_link'] ) ? $options['about_btn_link'] : '';
                $custom['image']        = ! empty( $options['about_image'] ) ? $options['about_image'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $about_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = travel_master_pro_trim_content( 35 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'travel_master_pro_filter_about_section_details', 'travel_master_pro_get_about_section_details' );


if ( ! function_exists( 'travel_master_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Travel Master Pro 1.0.0
   *
   */
   function travel_master_pro_render_about_section( $content_details = array() ) {
        $options = travel_master_pro_get_theme_options();
        $destinations = ! empty( $options['about_content_destination'] ) ? $options['about_content_destination'] : array();

        if ( empty( $content_details ) ) {
            return;
        } 

        foreach ( $content_details as $content ) : ?>

            <div id="about-us" class="relative page-section">
                <div class="wrapper">
                    <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                        <?php if ( ! empty( $content['image'] ) ) : ?>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"></div>
                        <?php endif; ?>

                        <div class="entry-container">
                            <header class="entry-header">
                                <?php if ( ! empty( $options['about_sub_title'] ) ) : ?>
                                    <p class="section-subtitle"><?php echo esc_html( $options['about_sub_title'] ); ?></p>
                                <?php endif;
                                
                                if ( ! empty( $content['title'] ) ) : ?>
                                    <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                <?php endif; ?>
                            </header>

                            <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                                <div class="entry-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                            <?php endif; ?>

                            <?php if ( ! empty( $content['url'] ) && ! empty( $options['about_btn_title'] ) ) : ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn">
                                        <span class="screen-reader-text"><?php echo esc_html( $content['title'] ); ?></span>
                                        <?php echo esc_html( $options['about_btn_title'] ); ?>
                                    </a>
                                </div><!-- .read-more -->
                            <?php endif; ?>

                            <?php if ( class_exists( 'WP_Travel' ) && ! empty( $destinations[0] ) ) : ?>
                                <div class="gallery-slider" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": true, "draggable": true, "fade": false }'>
                                    <?php foreach ( $destinations as $destination ) : 
                                        $cat = get_term_by( 'id', $destination, 'travel_locations' );
                                        $cat_image = get_term_meta( $destination, 'wp_travel_trip_type_image_id', true);
                                        $cat_image = ! empty( $cat_image ) ? wp_get_attachment_url( $cat_image ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                                        ?>
                                        <div class="gallery-item" style="background-image: url('<?php echo esc_url( $cat_image ); ?>');">
                                            <h2 class="gallery-title"><a href="<?php echo esc_url( get_term_link( $destination, 'travel_locations' ) ); ?>"><?php echo esc_html( $cat->name ); ?></a></h2>
                                        </div><!-- .gallery-item -->  
                                    <?php endforeach; ?>
                                </div><!-- .gallery-slider -->
                            <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #about-us -->

        <?php endforeach;
    }
endif;

